@@ -6,10 +6,11 @@ from evernote.edam.type.ttypes import Note
 from evernote.edam.type.ttypes import Resource, ResourceAttributes, Data
 # from evernote.edam.error import ttypes as errors
 from xml.sax.saxutils import escape
+from datetime import datetime
 from clint import textui
 import sys, os, argparse, mimetypes, hashlib, ConfigParser
-from datetime import datetime
 import keyring
+import chardet
 import config as sys_config
 
 
@@ -41,6 +42,7 @@ class ToEver():
             return textui.colored.red('Create note error')
 
         note_share_url = None
+        note_share_resource_url = None
         if self.share:
             note_share_url = ToEver.getNoteShareUrl(
                 sys_config.evernote_url,
@@ -48,12 +50,17 @@ class ToEver():
                 created_note.guid,
                 note_store.shareNote(self.token, created_note.guid)
             )
+            if resource is not None:
+                for x in created_note.resources:
+                    note_share_resource_url = note_share_url + "/res/%s/%s" % (x.guid, x.attributes.fileName)
 
         if not self.hide:
             message = "\n" + "Created note title is '" + title + "'"
             message += " [" + ToEver.getUserUploadState(note_store.getSyncState().uploaded, user_store.getUser().accounting.uploadLimitNextMonth) + "]"
             if note_share_url is not None:
                 message += "\n" + "Share URL --> " + note_share_url
+                if note_share_resource_url is not None:
+                    message += "\n" + "Share attachment URL --> " + note_share_resource_url
             print(textui.colored.blue(message))
         elif note_share_url is not None:
             print(textui.colored.blue(note_share_url))
@@ -146,15 +153,7 @@ class UserConfig():
 class Util():
     @staticmethod
     def isBinary(data):
-        for encoding in ['utf-8', 'shift-jis', 'euc-jp', 'iso2022-jp']:
-            try:
-                data = data.decode(encoding)
-                break
-            except:
-                pass
-        if isinstance(data, unicode):
-            return False
-        return True
+        return chardet.detect(data)['encoding'] is None
 
 
 def main():
